==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/EllipticalArc.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_
#define _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HDL_
#include "com/sun/star/geometry/EllipticalArc.hdl"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline EllipticalArc::EllipticalArc() SAL_THROW( () )
    : StartPosition()
    , EndPosition()
    , RadiusX(0)
    , RadiusY(0)
    , XAxisRotation(0)
    , IsLargeArc(false)
    , IsClockwiseSweep(false)
{
}

inline EllipticalArc::EllipticalArc(const ::com::sun::star::geometry::RealPoint2D& StartPosition_, const ::com::sun::star::geometry::RealPoint2D& EndPosition_, const double& RadiusX_, const double& RadiusY_, const double& XAxisRotation_, const ::sal_Bool& IsLargeArc_, const ::sal_Bool& IsClockwiseSweep_) SAL_THROW( () )
    : StartPosition(StartPosition_)
    , EndPosition(EndPosition_)
    , RadiusX(RadiusX_)
    , RadiusY(RadiusY_)
    , XAxisRotation(XAxisRotation_)
    , IsLargeArc(IsLargeArc_)
    , IsClockwiseSweep(IsClockwiseSweep_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::EllipticalArc const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.EllipticalArc");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/EllipticalArc.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_
#define _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HDL_
#include "com/sun/star/geometry/EllipticalArc.hdl"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline EllipticalArc::EllipticalArc() SAL_THROW( () )
    : StartPosition()
    , EndPosition()
    , RadiusX(0)
    , RadiusY(0)
    , XAxisRotation(0)
    , IsLargeArc(false)
    , IsClockwiseSweep(false)
{
}

inline EllipticalArc::EllipticalArc(const ::com::sun::star::geometry::RealPoint2D& StartPosition_, const ::com::sun::star::geometry::RealPoint2D& EndPosition_, const double& RadiusX_, const double& RadiusY_, const double& XAxisRotation_, const ::sal_Bool& IsLargeArc_, const ::sal_Bool& IsClockwiseSweep_) SAL_THROW( () )
    : StartPosition(StartPosition_)
    , EndPosition(EndPosition_)
    , RadiusX(RadiusX_)
    , RadiusY(RadiusY_)
    , XAxisRotation(XAxisRotation_)
    , IsLargeArc(IsLargeArc_)
    , IsClockwiseSweep(IsClockwiseSweep_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace geometry {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::geometry::EllipticalArc const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.EllipticalArc");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::EllipticalArc const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::geometry::EllipticalArc >::get();
}

#endif // _COM_SUN_STAR_GEOMETRY_ELLIPTICALARC_HPP_
